@@ -557,6 +557,24 @@ def test_CiscoRange_16():
     result_correct = [1, 2, 3]
     assert CiscoRange("", result_type=int).append("1-3").as_list == result_correct
 
+def test_CiscoRange_17():
+    """Parse a string with a common prefix on all of the CiscoRange() inputs"""
+    result_correct = [
+        "Eth1/1",
+        "Eth1/10",
+        "Eth1/12-20",
+    ]
+    CiscoRange("Eth1/1,Eth1/12-20,Eth1/16,Eth1/10").as_list == result_correct
+
+def test_CiscoRange_18():
+    """Parse a string with a common prefix on all of the CiscoRange() inputs"""
+    result_correct = [
+        "interface Eth1/1",
+        "interface Eth1/10",
+        "interface Eth1/12-20",
+    ]
+    CiscoRange("interface Eth1/1,interface Eth1/12-20,interface Eth1/16,interface Eth1/10").as_list == result_correct
+
 
 def test_CiscoRange_compressed_str_01():
     """compressed_str test"""
